@@ -1,4 +1,4 @@
 try:
     VERSION = __import__('pkg_resources').get_distribution('fabric-bolt').version
-except Exception, e:
+except Exception as e:
     VERSION = 'unknown'
\ No newline at end of file
